<?php
/**
 * Latest Posts Widget.
 */

defined( 'ABSPATH' ) || exit;

class Billow_Latest_Posts_Widget extends WP_Widget {

	/**
	 * Register widget.
	 */
	public function __construct() {

		$widget_ops = array(
			'classname'   => 'widget-latest-posts',
			'description' => esc_html( 'The widget shows latest posts.', 'billow' ),
		);

		$control_ops = array(
			'id_base' => 'billow_latest_posts_widget',
		);

		parent::__construct( 'billow_latest_posts_widget', 'Latest Posts Widget', $widget_ops, $control_ops );
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		echo $args['before_widget']; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		?>

			<ul class="widget latest-posts">
				<?php query_posts( 'showposts=2' ); ?>

				<h2 class="widget-title"><?php esc_html( 'Latest Posts', 'billow' ); ?></h2>

				<?php while ( have_posts() ) : the_post(); ?>
				<li class="widget-holder">

					<?php billow_post_thumbnail(); ?>

					<div class="content">
						<a href="<?php the_permalink() ?>" class="post-title" rel="bookmark" title="<?php the_title(); ?>"><?php the_title(); ?></a>
						<div class="post-meta">
							<a href="<?php the_permalink() ?>" class="date-link">
								<time class="post-date" <?php the_permalink() ?> datetime="<?php echo esc_attr( get_the_date( DATE_W3C ) ); ?>">
									<?php echo esc_html( get_the_date( 'M d Y' ) ); ?>
								</time>
							</a>
						</div>
					</div>

				</li>
				<?php
				endwhile;
				// Reset the global $the_post as this query will have stomped on it
				wp_reset_postdata();
				?>
			</ul>

		<?php
		echo $args['after_widget']; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		// outputs the options form on admin
		$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html( '', 'billow' );
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html( 'Title:', 'billow' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		// processes widget options to be saved
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';

		return $instance;
	}
}
