/* global wp, jQuery */
/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {
	// Site title and description
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title, .site-description' ).css( {
					clip: 'rect(1px, 1px, 1px, 1px)',
					position: 'absolute',
				} );
			} else {
				$( '.site-title, .site-description' ).css( {
					clip: 'auto',
					position: 'relative',
				} );
				$( '.site-title a, .site-description' ).css( {
					color: to,
				} );
			}
		} );
	} );

	// Global
	wp.customize( 'billow_site_max_width', function( value ) {
		value.bind( function( to ) {
			$('.billow .container')
				.css('max-width', to + 'px' );
		} );
	} );

	wp.customize( 'billow_site_padding', function( value ) {
		value.bind( function( to ) {
			$('.billow .container').css('padding-left', to + 'px' );
			$('.billow .container').css('padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'billow_content_padding_top', function( value ) {
		value.bind( function( to ) {
			$('.billow .site-content > .container').css('padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'billow_content_padding_bottom', function( value ) {
		value.bind( function( to ) {
			$('.billow .site-content > .container').css('padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'billow_base_color', function( value ) {
		value.bind( function( to ) {
			$('body.billow, .billow .site p, .billow .site button, .billow .site input, .billow .site select, .billow .site optgroup, .billow .site textarea, .billow .site span').css('color', to );
		} );
	} );

	wp.customize( 'billow_link_color', function( value ) {
		value.bind( function( to ) {
			$('body.billow, .billow .site a, .billow .site a:visited').css('color', to );
		} );
	} );

	wp.customize( 'billow_link_hover_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .site a:hover').css('color', to );
		} );
	} );

	wp.customize( 'billow_heading_color', function( value ) {
		value.bind( function( to ) {
			$('.billow h1, .billow h2, .billow h3, .billow h4, .billow h5, .billow h6, .billow .entry-title > a, .billow span.title').css('color', to );
		} );
	} );

	wp.customize( 'billow_button_font_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"]').css('color', to );
			$('.billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon').css('color', to );
			$('.billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('color', to );
			$('.billow.theme-style-yellow .button:not(.customize-partial-edit-shortcut-button), .billow.theme-style-yellow input[type="button"], .billow.theme-style-yellow input[type="reset"], .billow.theme-style-yellow input[type="submit"], .billow.theme-style-yellow button[type="submit"]').css('color', to );
			$('.billow.theme-style-yellow #page .woocommerce a.button, .billow.theme-style-yellow #page .widget-area a.add_to_cart_button, .billow.theme-style-yellow #page .woocommerce-info a.button, .billow.theme-style-yellow #page .woocommerce-info a.showcoupon, .billow.theme-style-yellow #page .woocommerce-message a.button, .billow.theme-style-yellow #page .woocommerce-message a.showcoupon, .billow.theme-style-yellow #page .woocommerce-error a.button, .billow.theme-style-yellow #page .woocommerce-error a.showcoupon').css('color', to );
			$('.billow.theme-style-yellow #page .single-product-wrapper a.button, .billow.theme-style-yellow #page .single-product-wrapper a.added_to_cart, .billow.theme-style-yellow #page .woocommerce-pagination ul.page-numbers li .current, .billow.theme-style-yellow #page .navigation.pagination .nav-links > *.current').css('color', to );
			$('.billow.theme-style-yellow #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active a, .billow.theme-style-yellow #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li:hover a').css('color', to );
		} );
	} );

	wp.customize( 'billow_button_bc_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('background-color', to );
			
			$('.billow.theme-style-green .button:not(.customize-partial-edit-shortcut-button), .billow.theme-style-green input[type="button"], .billow.theme-style-green input[type="reset"], .billow.theme-style-green input[type="submit"], .billow.theme-style-green button[type="submit"], .billow.theme-style-green #page .woocommerce a.button, .billow.theme-style-green #page .widget-area a.add_to_cart_button, .billow.theme-style-green #page .woocommerce-info a.button, .billow.theme-style-green #page .woocommerce-info a.showcoupon, .billow.theme-style-green #page .woocommerce-message a.button, .billow.theme-style-green #page .woocommerce-message a.showcoupon, .billow.theme-style-green #page .woocommerce-error a.button, .billow.theme-style-green #page .woocommerce-error a.showcoupon, .billow.theme-style-green #page .single-product-wrapper a.button, .billow.theme-style-green #page .single-product-wrapper a.added_to_cart, .billow.theme-style-green #page .woocommerce-pagination ul.page-numbers li .current, .billow.theme-style-green #page .navigation.pagination .nav-links > *.current').css('background-color', to );
			$('.billow.theme-style-green #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active a, .billow.theme-style-green #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li:hover a').css('background-color', to );
			$('.billow.theme-style-green form.search-form button.search-submit, .billow.theme-style-green .widget_product_search .woocommerce-product-search button, .billow.theme-style-green .mobile-menu-container.off a.close i').css('color', to );
			$('.billow.theme-style-green form.search-form button.search-submit:hover, .billow.theme-style-green .widget_product_search .woocommerce-product-search button:hover').css('color', to );
			
			$('.billow.theme-style-violet .button:not(.customize-partial-edit-shortcut-button), .billow.theme-style-violet input[type="button"], .billow.theme-style-violet input[type="reset"], .billow.theme-style-violet input[type="submit"], .billow.theme-style-violet button[type="submit"], .billow.theme-style-violet #page .woocommerce a.button, .billow.theme-style-violet #page .widget-area a.add_to_cart_button, .billow.theme-style-violet #page .woocommerce-info a.button, .billow.theme-style-violet #page .woocommerce-info a.showcoupon, .billow.theme-style-violet #page .woocommerce-message a.button, .billow.theme-style-violet #page .woocommerce-message a.showcoupon, .billow.theme-style-violet #page .woocommerce-error a.button, .billow.theme-style-violet #page .woocommerce-error a.showcoupon, .billow.theme-style-violet #page .single-product-wrapper a.button, .billow.theme-style-violet #page .single-product-wrapper a.added_to_cart, .billow.theme-style-violet #page .woocommerce-pagination ul.page-numbers li .current, .billow.theme-style-violet #page .navigation.pagination .nav-links > *.current').css('background-color', to );
			$('.billow.theme-style-violet #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active a, .billow.theme-style-violet #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li:hover a').css('background-color', to );
			$('.billow.theme-style-violet form.search-form button.search-submit, .billow.theme-style-violet .widget_product_search .woocommerce-product-search button, .billow.theme-style-violet header.site-header .header-wrap .container .main-navigation button.menu-toggle::before, .billow.theme-style-violet .mobile-menu-container.off a.close i').css('color', to );
			$('.billow.theme-style-violet form.search-form button.search-submit:hover, .billow.theme-style-violet .widget_product_search .woocommerce-product-search button:hover').css('color', to );
			
			$('.billow.theme-style-yellow .button:not(.customize-partial-edit-shortcut-button), .billow.theme-style-yellow input[type="button"], .billow.theme-style-yellow input[type="reset"], .billow.theme-style-yellow input[type="submit"], .billow.theme-style-yellow button[type="submit"], .billow.theme-style-yellow #page .woocommerce a.button, .billow.theme-style-yellow #page .widget-area a.add_to_cart_button, .billow.theme-style-yellow #page .woocommerce-info a.button, .billow.theme-style-yellow #page .woocommerce-info a.showcoupon, .billow.theme-style-yellow #page .woocommerce-message a.button, .billow.theme-style-yellow #page .woocommerce-message a.showcoupon, .billow.theme-style-yellow #page .woocommerce-error a.button, .billow.theme-style-yellow #page .woocommerce-error a.showcoupon, .billow.theme-style-yellow #page .single-product-wrapper a.button, .billow.theme-style-yellow #page .single-product-wrapper a.added_to_cart, .billow.theme-style-yellow #page .woocommerce-pagination ul.page-numbers li .current, .billow.theme-style-yellow #page .navigation.pagination .nav-links > *.current').css('background-color', to );
			$('.billow.theme-style-yellow #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active a, .billow.theme-style-yellow #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li:hover a').css('background-color', to );
			$('.billow.theme-style-yellow form.search-form button.search-submit, .billow.theme-style-yellow .widget_product_search .woocommerce-product-search button, .billow.theme-style-yellow header.site-header .header-wrap .container .main-navigation button.menu-toggle::before, .billow.theme-style-yellow .mobile-menu-container.off a.close i').css('color', to );
			$('.billow.theme-style-yellow form.search-form button.search-submit:hover, .billow.theme-style-yellow .widget_product_search .woocommerce-product-search button:hover').css('color', to );
		} );
	} );

	wp.customize( 'billow_button_hover_font_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button):hover, .billow input[type="button"]:hover, .billow input[type="reset"]:hover, .billow input[type="submit"]:hover, .billow button[type="submit"]:hover, .billow #page .woocommerce a.button:hover, .billow #page .widget-area a.add_to_cart_button:hover, .billow #page .woocommerce-info a.button:hover, .billow #page .woocommerce-info a.showcoupon:hover, .billow #page .woocommerce-message a.button:hover, .billow #page .woocommerce-message a.showcoupon:hover, .billow #page .woocommerce-error a.button:hover, .billow #page .woocommerce-error a.showcoupon:hover, .billow #page .single-product-wrapper a.button:hover, .billow #page .single-product-wrapper a.added_to_cart:hover, .billow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow #page .navigation.pagination .nav-links > *.current:hover').css('color', to );
			
			$('.billow.theme-style-yellow .button:not(.customize-partial-edit-shortcut-button):hover, .billow.theme-style-yellow input[type="button"]:hover, .billow.theme-style-yellow input[type="reset"]:hover, .billow.theme-style-yellow input[type="submit"]:hover, .billow.theme-style-yellow button[type="submit"]:hover, .billow.theme-style-yellow #page .woocommerce a.button:hover, .billow.theme-style-yellow #page .widget-area a.add_to_cart_button:hover, .billow.theme-style-yellow #page .woocommerce-info a.button:hover, .billow.theme-style-yellow #page .woocommerce-info a.showcoupon:hover, .billow.theme-style-yellow #page .woocommerce-message a.button:hover, .billow.theme-style-yellow #page .woocommerce-message a.showcoupon:hover, .billow.theme-style-yellow #page .woocommerce-error a.button:hover, .billow.theme-style-yellow #page .woocommerce-error a.showcoupon:hover, .billow.theme-style-yellow #page .single-product-wrapper a.button:hover, .billow.theme-style-yellow #page .single-product-wrapper a.added_to_cart:hover, .billow.theme-style-yellow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow.theme-style-yellow #page .navigation.pagination .nav-links > *.current:hover').css('color', to );
			$('.billow.theme-style-yellow #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active:hover a').css('color', to );
			$('.billow.theme-style-yellow.error404 section.error-404 .first-section .search-content a.backhome:hover').css('color', to );
		} );
	} );

	wp.customize( 'billow_button_hover_bc_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button):hover, .billow input[type="button"]:hover, .billow input[type="reset"]:hover, .billow input[type="submit"]:hover, .billow button[type="submit"]:hover, .billow #page .woocommerce a.button:hover, .billow #page .widget-area a.add_to_cart_button:hover, .billow #page .woocommerce-info a.button:hover, .billow #page .woocommerce-info a.showcoupon:hover, .billow #page .woocommerce-message a.button:hover, .billow #page .woocommerce-message a.showcoupon:hover, .billow #page .woocommerce-error a.button:hover, .billow #page .woocommerce-error a.showcoupon:hover, .billow #page .single-product-wrapper a.button:hover, .billow #page .single-product-wrapper a.added_to_cart:hover, .billow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow #page .navigation.pagination .nav-links > *.current:hover').css('background-color', to );
			
			$('.billow.theme-style-green .button:not(.customize-partial-edit-shortcut-button):hover, .billow.theme-style-green input[type="button"]:hover, .billow.theme-style-green input[type="reset"]:hover, .billow.theme-style-green input[type="submit"]:hover, .billow.theme-style-green button[type="submit"]:hover, .billow.theme-style-green #page .woocommerce a.button:hover, .billow.theme-style-green #page .woocommerce-info a.button:hover, .billow.theme-style-green #page .woocommerce-info a.showcoupon:hover, .billow.theme-style-green #page .woocommerce-message a.button:hover, .billow.theme-style-green #page .woocommerce-message a.showcoupon:hover, .billow.theme-style-green #page .woocommerce-error a.button:hover, .billow.theme-style-green #page .woocommerce-error a.showcoupon:hover, .billow.theme-style-green #page .single-product-wrapper a.button:hover, .billow.theme-style-green #page .single-product-wrapper a.added_to_cart:hover, .billow.theme-style-green #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow.theme-style-green #page .navigation.pagination .nav-links > *.current:hover').css('background-color', to );
			$('.billow.theme-style-green #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active:hover a').css('background-color', to );
			
			$('.billow.theme-style-violet .button:not(.customize-partial-edit-shortcut-button):hover, .billow.theme-style-violet input[type="button"]:hover, .billow.theme-style-violet input[type="reset"]:hover, .billow.theme-style-violet input[type="submit"]:hover, .billow.theme-style-violet button[type="submit"]:hover, .billow.theme-style-violet #page .woocommerce a.button:hover, .billow.theme-style-violet #page .widget-area a.add_to_cart_button:hover, .billow.theme-style-violet #page .woocommerce-info a.button:hover, .billow.theme-style-violet #page .woocommerce-info a.showcoupon:hover, .billow.theme-style-violet #page .woocommerce-message a.button:hover, .billow.theme-style-violet #page .woocommerce-message a.showcoupon:hover, .billow.theme-style-violet #page .woocommerce-error a.button:hover, .billow.theme-style-violet #page .woocommerce-error a.showcoupon:hover, .billow.theme-style-violet #page .single-product-wrapper a.button:hover, .billow.theme-style-violet #page .single-product-wrapper a.added_to_cart:hover, .billow.theme-style-violet #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow.theme-style-violet #page .navigation.pagination .nav-links > *.current:hover').css('background-color', to );
			$('.billow.theme-style-violet #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active:hover a').css('background-color', to );
			$('.billow.theme-style-yellow .button:not(.customize-partial-edit-shortcut-button):hover, .billow.theme-style-yellow input[type="button"]:hover, .billow.theme-style-yellow input[type="reset"]:hover, .billow.theme-style-yellow input[type="submit"]:hover, .billow.theme-style-yellow button[type="submit"]:hover, .billow.theme-style-yellow #page .woocommerce a.button:hover, .billow.theme-style-yellow #page .widget-area a.add_to_cart_button:hover, .billow.theme-style-yellow #page .woocommerce-info a.button:hover, .billow.theme-style-yellow #page .woocommerce-info a.showcoupon:hover, .billow.theme-style-yellow #page .woocommerce-message a.button:hover, .billow.theme-style-yellow #page .woocommerce-message a.showcoupon:hover, .billow.theme-style-yellow #page .woocommerce-error a.button:hover, .billow.theme-style-yellow #page .woocommerce-error a.showcoupon:hover, .billow.theme-style-yellow #page .single-product-wrapper a.button:hover, .billow.theme-style-yellow #page .single-product-wrapper a.added_to_cart:hover, .billow.theme-style-yellow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow.theme-style-yellow #page .navigation.pagination .nav-links > *.current:hover').css('background-color', to );
			$('.billow.theme-style-yellow #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active:hover a').css('background-color', to );
		} );
	} );

	wp.customize( 'billow_button_border', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('border-width', to + 'px' );
		} );
	} );
	
	wp.customize( 'billow_button_border_style', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('border-style', to );
		} );
	} );
	
	wp.customize( 'billow_button_border_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('border-color', to );
		} );
	} );
	
	wp.customize( 'billow_button_hover_border', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button):hover, .billow input[type="button"]:hover, .billow input[type="reset"]:hover, .billow input[type="submit"]:hover, .billow button[type="submit"]:hover, .billow #page .woocommerce a.button:hover, .billow #page .widget-area a.add_to_cart_button:hover, .billow #page .woocommerce-info a.button:hover, .billow #page .woocommerce-info a.showcoupon:hover, .billow #page .woocommerce-message a.button:hover, .billow #page .woocommerce-message a.showcoupon:hover, .billow #page .woocommerce-error a.button:hover, .billow #page .woocommerce-error a.showcoupon:hover, .billow #page .single-product-wrapper a.button:hover, .billow #page .single-product-wrapper a.added_to_cart:hover, .billow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow #page .navigation.pagination .nav-links > *.current:hover').css('border-width', to + 'px' );
		} );
	} );
	
	wp.customize( 'billow_button_hover_border_style', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button):hover, .billow input[type="button"]:hover, .billow input[type="reset"]:hover, .billow input[type="submit"]:hover, .billow button[type="submit"]:hover, .billow #page .woocommerce a.button:hover, .billow #page .widget-area a.add_to_cart_button:hover, .billow #page .woocommerce-info a.button:hover, .billow #page .woocommerce-info a.showcoupon:hover, .billow #page .woocommerce-message a.button:hover, .billow #page .woocommerce-message a.showcoupon:hover, .billow #page .woocommerce-error a.button:hover, .billow #page .woocommerce-error a.showcoupon:hover, .billow #page .single-product-wrapper a.button:hover, .billow #page .single-product-wrapper a.added_to_cart:hover, .billow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow #page .navigation.pagination .nav-links > *.current:hover').css('border-style', to );
		} );
	} );
	
	wp.customize( 'billow_button_hover_border_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button):hover, .billow input[type="button"]:hover, .billow input[type="reset"]:hover, .billow input[type="submit"]:hover, .billow button[type="submit"]:hover, .billow #page .woocommerce a.button:hover, .billow #page .widget-area a.add_to_cart_button:hover, .billow #page .woocommerce-info a.button:hover, .billow #page .woocommerce-info a.showcoupon:hover, .billow #page .woocommerce-message a.button:hover, .billow #page .woocommerce-message a.showcoupon:hover, .billow #page .woocommerce-error a.button:hover, .billow #page .woocommerce-error a.showcoupon:hover, .billow #page .single-product-wrapper a.button:hover, .billow #page .single-product-wrapper a.added_to_cart:hover, .billow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow #page .navigation.pagination .nav-links > *.current:hover').css('border-color', to );
		} );
	} );
	
	wp.customize( 'billow_button_border_radius_top_left', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('border-top-left-radius', to + 'px' );
		} );
	} );
	
	wp.customize( 'billow_button_border_radius_top_right', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('border-top-right-radius', to + 'px' );
		} );
	} );

	wp.customize( 'billow_button_border_radius_bottom_left', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('border-bottom-left-radius', to + 'px' );
		} );
	} );

	wp.customize( 'billow_button_border_radius_bottom_right', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('border-bottom-right-radius', to + 'px' );
		} );
	} );

	wp.customize( 'billow_button_border_radius_top_left', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button):hover, .billow input[type="button"]:hover, .billow input[type="reset"]:hover, .billow input[type="submit"]:hover, .billow button[type="submit"]:hover, .billow #page .woocommerce a.button:hover, .billow #page .widget-area a.add_to_cart_button:hover, .billow #page .woocommerce-info a.button:hover, .billow #page .woocommerce-info a.showcoupon:hover, .billow #page .woocommerce-message a.button:hover, .billow #page .woocommerce-message a.showcoupon:hover, .billow #page .woocommerce-error a.button:hover, .billow #page .woocommerce-error a.showcoupon:hover, .billow #page .single-product-wrapper a.button:hover, .billow #page .single-product-wrapper a.added_to_cart:hover, .billow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow #page .navigation.pagination .nav-links > *.current:hover').css('border-top-left-radius', to + 'px' );
		} );
	} );
	
	wp.customize( 'billow_button_border_radius_top_right', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button):hover, .billow input[type="button"]:hover, .billow input[type="reset"]:hover, .billow input[type="submit"]:hover, .billow button[type="submit"]:hover, .billow #page .woocommerce a.button:hover, .billow #page .widget-area a.add_to_cart_button:hover, .billow #page .woocommerce-info a.button:hover, .billow #page .woocommerce-info a.showcoupon:hover, .billow #page .woocommerce-message a.button:hover, .billow #page .woocommerce-message a.showcoupon:hover, .billow #page .woocommerce-error a.button:hover, .billow #page .woocommerce-error a.showcoupon:hover, .billow #page .single-product-wrapper a.button:hover, .billow #page .single-product-wrapper a.added_to_cart:hover, .billow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow #page .navigation.pagination .nav-links > *.current:hover').css('border-top-right-radius', to + 'px' );
		} );
	} );

	wp.customize( 'billow_button_border_radius_bottom_left', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button):hover, .billow input[type="button"]:hover, .billow input[type="reset"]:hover, .billow input[type="submit"]:hover, .billow button[type="submit"]:hover, .billow #page .woocommerce a.button:hover, .billow #page .widget-area a.add_to_cart_button:hover, .billow #page .woocommerce-info a.button:hover, .billow #page .woocommerce-info a.showcoupon:hover, .billow #page .woocommerce-message a.button:hover, .billow #page .woocommerce-message a.showcoupon:hover, .billow #page .woocommerce-error a.button:hover, .billow #page .woocommerce-error a.showcoupon:hover, .billow #page .single-product-wrapper a.button:hover, .billow #page .single-product-wrapper a.added_to_cart:hover, .billow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow #page .navigation.pagination .nav-links > *.current:hover').css('border-bottom-left-radius', to + 'px' );
		} );
	} );

	wp.customize( 'billow_button_border_radius_bottom_right', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button):hover, .billow input[type="button"]:hover, .billow input[type="reset"]:hover, .billow input[type="submit"]:hover, .billow button[type="submit"]:hover, .billow #page .woocommerce a.button:hover, .billow #page .widget-area a.add_to_cart_button:hover, .billow #page .woocommerce-info a.button:hover, .billow #page .woocommerce-info a.showcoupon:hover, .billow #page .woocommerce-message a.button:hover, .billow #page .woocommerce-message a.showcoupon:hover, .billow #page .woocommerce-error a.button:hover, .billow #page .woocommerce-error a.showcoupon:hover, .billow #page .single-product-wrapper a.button:hover, .billow #page .single-product-wrapper a.added_to_cart:hover, .billow #page .woocommerce-pagination ul.page-numbers li .current:hover, .billow #page .navigation.pagination .nav-links > *.current:hover').css('border-bottom-right-radius', to + 'px' );
		} );
	} );

	wp.customize( 'billow_scroll_top_icon_color', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer #scroll-to-top span::before').css('color', to );
			$('.billow.theme-style-yellow footer.site-footer #scroll-to-top:hover span::before').css('color', to );
			$('.billow.theme-style-yellow footer.site-footer #scroll-to-top:hover span::before').css('color', to );
		} );
	} );
	
	// Header
	wp.customize( 'billow_header_border_bottom', function( value ) {
		value.bind( function( to ) {
			$('.billow #page header.site-header').css('border-bottom-width', to + 'px' );
		} );
	} );

	wp.customize( 'billow_header_border_bottom_style', function( value ) {
		value.bind( function( to ) {
			$('.billow #page header.site-header').css('border-bottom-style', to );
		} );
	} );

	wp.customize( 'billow_header_border_bottom_color', function( value ) {
		value.bind( function( to ) {
			$('.billow #page header.site-header').css('border-bottom-color', to );
		} );
	} );

	wp.customize( 'billow_header_bar_margin_top', function( value ) {
		value.bind( function( to ) {
			$('.billow #page header.site-header').css('margin-top', to + 'px' );
		} );
	} );

	wp.customize( 'billow_header_bar_margin_bottom', function( value ) {
		value.bind( function( to ) {
			$('.billow #page header.site-header').css('margin-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'billow_header_bar_padding_top', function( value ) {
		value.bind( function( to ) {
			$('.billow #page header.site-header').css('padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'billow_header_bar_padding_bottom', function( value ) {
		value.bind( function( to ) {
			$('.billow #page header.site-header').css('padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'site_title_font', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding .site-title' ).css( 'font-family', to );
        } );
    } );

	wp.customize( 'site_title_font_size', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding .site-title' ).css( 'font-size', to );
        } );
    } );

	wp.customize( 'site_title_font_line_height', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding .site-title' ).css( 'line-height', to );
        } );
    } );

	wp.customize( 'site_title_font_weight', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding .site-title' ).css( 'font-weight', to );
        } );
    } );

	wp.customize( 'site_title_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding .site-title' ).css( 'letter-spacing', to );
        } );
    } );

	wp.customize( 'site_title_font_text_transform', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding .site-title' ).css( 'text-transform', to );
        } );
    } );

	wp.customize( 'title_tagline_font', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding p.site-description' ).css( 'font-family', to );
        } );
    } );

	wp.customize( 'title_tagline_font_size', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding p.site-description' ).css( 'font-size', to );
        } );
    } );

	wp.customize( 'title_tagline_font_line_height', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding p.site-description' ).css( 'line-height', to );
        } );
    } );

	wp.customize( 'title_tagline_font_weight', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding p.site-description' ).css( 'font-weight', to );
        } );
    } );

	wp.customize( 'title_tagline_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding p.site-description' ).css( 'letter-spacing', to );
        } );
    } );

	wp.customize( 'title_tagline_font_text_transform', function( value ) {
        value.bind( function( to ) {
            $( '.billow header.site-header .header-wrap .container .main-info .site-branding p.site-description' ).css( 'text-transform', to );
        } );
    } );

	wp.customize( 'billow_menu_height', function( value ) {
        value.bind( function( to ) {
            $( '.billow .main-navigation div > ul > li > a' ).css( 'height', to );
        } );
    } );

	wp.customize( 'billow_menu_item_padding', function( value ) {
        value.bind( function( to ) {
			$( '.billow .main-navigation ul > li > a' ).css( 'padding-left', to );
            $( '.billow .main-navigation ul > li > a' ).css( 'padding-right', to );
        } );
    } );

	wp.customize( 'billow_menu_link_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow header.site-header .header-wrap .container nav.main-navigation ul > li > a' ).css( 'color', to );
			$( '.billow.theme-style-violet header.site-header .header-wrap .container nav.main-navigation ul > li > a' ).css( 'color', to );
        } );
    } );

	wp.customize( 'billow_menu_hover_link_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow header.site-header .header-wrap .container nav.main-navigation ul > li > a:hover' ).css( 'color', to );
			$( '.billow.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li.current-menu-item > a, .billow.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li:hover > a' ).css( 'color', to );
			$( '.billow.theme-style-violet header.site-header .header-wrap .container nav.main-navigation ul > li > a:hover' ).css( 'color', to );
			$( '.billow.theme-style-violet.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li.current-menu-item > a, .billow.theme-style-violet.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li:hover > a' ).css( 'color', to );
			$( '.billow.theme-style-yellow header.site-header .header-wrap .container nav.main-navigation ul > li > a:hover' ).css( 'color', to );
			$( '.billow.theme-style-yellow.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li.current-menu-item > a, .billow.theme-style-yellow.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li:hover > a' ).css( 'color', to );
        } );
    } );

	wp.customize( 'billow_menu_dropdown_link_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow .site-header .header-wrap .container .main-navigation ul.menu li ul li a' ).css( 'color', to );
			$( '.billow.theme-style-violet .site-header .header-wrap .container .main-navigation ul.menu li ul li a' ).css( 'color', to );
			$( '.billow.theme-style-yellow header.site-header .header-wrap .container nav.main-navigation ul > li > a' ).css( 'color', to );
        } );
    } );

	wp.customize( 'billow_menu_dropdown_hover_link_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow .site-header .header-wrap .container .main-navigation ul.menu li ul li a:hover, .billow .site-header .header-wrap .container .main-navigation ul.menu li ul li:hover > a' ).css( 'color', to );
			$( '.billow.theme-style-violet .site-header .header-wrap .container .main-navigation ul.menu li ul li a:hover, .billow.theme-style-violet .site-header .header-wrap .container .main-navigation ul.menu li ul li:hover > a' ).css( 'color', to );
			$( '.billow.theme-style-yellow .site-header .header-wrap .container .main-navigation ul.menu li ul li a:hover, .billow.theme-style-yellow .site-header .header-wrap .container .main-navigation ul.menu li ul li:hover > a' ).css( 'color', to );
        } );
    } );

	wp.customize( 'billow_menu_dropdown_hover_link_bc_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow .site-header .header-wrap .container .main-navigation ul.menu li ul li:hover > a' ).css( 'background-color', to );
			$( '.billow.theme-style-green #page .main-navigation ul.menu li ul li:hover > a' ).css( 'background-color', to );
			$( '.billow.theme-style-violet #page .site-header .main-navigation ul.menu li ul li:hover > a' ).css( 'background-color', to );
			$( '.billow.theme-style-yellow #page .main-navigation ul.menu li ul li:hover > a' ).css( 'background-color', to );
        } );
    } );

	wp.customize( 'billow_menu_dropdown_bc_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow .site-header .header-wrap .container .main-navigation ul.menu li ul' ).css( 'background-color', to );
			$( '.billow.theme-style-green #page .site-header .main-navigation ul.menu li ul' ).css( 'background-color', to );
			$( '.billow.theme-style-violet #page .site-header .main-navigation ul.menu li ul' ).css( 'background-color', to );
			$( '.billow.theme-style-yellow #page .site-header .main-navigation ul.menu li ul' ).css( 'background-color', to );
        } );
    } );

	wp.customize( 'billow_header_bc_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow:not(.home) header#masthead.site-header' ).css( 'background-color', to );
			$( '.billow.theme-style-green:not(.home) header#masthead.site-header' ).css( 'background-color', to );
			$( '.billow.theme-style-violet:not(.home) header#masthead.site-header' ).css( 'background-color', to );
			$( '.billow.theme-style-yellow:not(.home) header#masthead.site-header' ).css( 'background-color', to );
        } );
    } );

	// Home Page
	wp.customize( 'billow_home_page_vertical_align', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content' ).css( 'justify-content', to );
        } );
    } );

	wp.customize( 'billow_home_page_layout_padding_top', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content' ).css( 'padding-top', to );
        } );
    } );

	wp.customize( 'billow_home_page_layout_padding_right', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content' ).css( 'padding-right', to );
        } );
    } );

	wp.customize( 'billow_home_page_layout_padding_bottom', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content' ).css( 'padding-bottom', to );
        } );
    } );

	wp.customize( 'billow_home_page_layout_padding_left', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content' ).css( 'padding-left', to );
        } );
    } );

	wp.customize( 'billow_home_page_bar_bc', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home header.site-header' ).css( 'background-color', to );
			$( '.billow.home.sticky-menu header.site-header.float-header' ).css( 'background-color', to );
			$( '.billow.theme-style-green.home header.site-header, .billow.theme-style-green.home.sticky-menu header.site-header' ).css( 'background-color', to );
			$( '.billow.theme-style-violet.home header.site-header, .billow.theme-style-violet.home header.site-header.fixed, .billow.theme-style-violet.home.sticky-menu header.site-header' ).css( 'background-color', to );
			$( '.billow.theme-style-yellow.home header.site-header, .billow.theme-style-yellow.home header.site-header.fixed, .billow.theme-style-yellow.home.sticky-menu header.site-header' ).css( 'background-color', to );
        } );
    } );

	wp.customize( 'billow_home_page_bc_overlay_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-bg::after' ).css( 'background-color', to );
			$( '.billow.theme-style-green.home .blw-hero-area .hero-bg::after' ).css( 'background-color', to );
			$( '.billow.theme-style-violet.home .blw-hero-area .hero-bg::after' ).css( 'background-color', to );
			$( '.billow.theme-style-yellow.home .blw-hero-area .hero-bg::after' ).css( 'background-color', to );
		} );
    } );

	wp.customize( 'billow_home_page_title_font_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content .hero-title .entry-title' ).css( 'color', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_font_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'color', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_bc_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'background-color', to );
			$( '.billow.theme-style-green.home .hero-content a.button-slider' ).css( 'background-color', to );
			$( '.billow.theme-style-violet.home .hero-content a.button-slider' ).css( 'background-color', to );
			$( '.billow.theme-style-yellow.home .hero-content a.button-slider' ).css( 'background-color', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_hover_font_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider:hover' ).css( 'color', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_hover_bc_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider:hover' ).css( 'background-color', to );
			$( '.billow.theme-style-green.home .hero-content a.button-slider:hover' ).css( 'background-color', to );
			$( '.billow.theme-style-violet.home .hero-content a.button-slider:hover' ).css( 'background-color', to );
			$( '.billow.theme-style-yellow.home .hero-content a.button-slider:hover' ).css( 'background-color', to );
		} );
    } );

	wp.customize( 'billow_home_page_title_font_size', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content .hero-title .entry-title' ).css( 'font-size', to );
		} );
    } );

	wp.customize( 'billow_home_page_title_font_line_height', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content .hero-title .entry-title' ).css( 'line-height', to );
		} );
    } );

	wp.customize( 'billow_home_page_title_font_weight', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content .hero-title .entry-title' ).css( 'font-weight', to );
		} );
    } );

	wp.customize( 'billow_home_page_title_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content .hero-title .entry-title' ).css( 'letter-spacing', to );
		} );
    } );

	wp.customize( 'billow_home_page_title_font_text_transform', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .blw-hero-area .hero-content .hero-title .entry-title' ).css( 'text-transform', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_font_size', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'font-size', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_font_weight', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'font-weight', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_font_line_height', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'line-height', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'letter-spacing', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_font_text_transform', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'text-transform', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_border', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'border-width', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_border_style', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'border-style', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_border_color', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'border-color', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_border_radius_top_left', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'border-top-left-radius', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_border_radius_top_right', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'border-top-right-radius', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_border_radius_bottom_left', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'border-bottom-left-radius', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_border_radius_bottom_right', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider' ).css( 'border-bottom-right-radius', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_hover_border_radius_top_left', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider:hover' ).css( 'border-top-left-radius', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_hover_border_radius_top_right', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider:hover' ).css( 'border-top-right-radius', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_hover_border_radius_bottom_left', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider:hover' ).css( 'border-bottom-left-radius', to );
		} );
    } );

	wp.customize( 'billow_home_page_button_hover_border_radius_bottom_right', function( value ) {
        value.bind( function( to ) {
			$( '.billow.home .hero-content a.button-slider:hover' ).css( 'border-bottom-right-radius', to );
		} );
    } );

	// Typography
	wp.customize( 'billow_base_font', function( value ) {
        value.bind( function( to ) {
			$( 'body.billow, .billow p, .billow button, .billow input, .billow select, .billow optgroup, .billow textarea' ).css( 'font-family', to );
		} );
    } );

	wp.customize( 'billow_base_font_size', function( value ) {
        value.bind( function( to ) {
			$( 'body.billow, .billow p, .billow button, .billow input, .billow select, .billow optgroup, .billow textarea' ).css( 'font-size', to );
		} );
    } );

	wp.customize( 'billow_base_font_line_height', function( value ) {
        value.bind( function( to ) {
			$( 'body.billow, .billow p, .billow button, .billow input, .billow select, .billow optgroup, .billow textarea' ).css( 'line-height', to );
		} );
    } );

	wp.customize( 'billow_base_font_weight', function( value ) {
        value.bind( function( to ) {
			$( 'body.billow, .billow p, .billow button, .billow input, .billow select, .billow optgroup, .billow textarea' ).css( 'font-weight', to );
		} );
    } );

	wp.customize( 'billow_base_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
			$( 'body.billow, .billow p, .billow button, .billow input, .billow select, .billow optgroup, .billow textarea' ).css( 'letter-spacing', to );
		} );
    } );

	wp.customize( 'billow_base_font_text_transform', function( value ) {
        value.bind( function( to ) {
			$( 'body.billow, .billow p, .billow button, .billow input, .billow select, .billow optgroup, .billow textarea' ).css( 'text-transform', to );
		} );
    } );

	// Heading H1
	wp.customize( 'billow_heading1_font', function( value ) {
        value.bind( function( to ) {
			$( '.billow h1' ).css( 'font-family', to );
		} );
    } );

	wp.customize( 'billow_heading1_font_size', function( value ) {
        value.bind( function( to ) {
			$( '.billow h1' ).css( 'font-size', to );
		} );
    } );

	wp.customize( 'billow_heading1_font_line_height', function( value ) {
        value.bind( function( to ) {
			$( '.billow h1' ).css( 'line-height', to );
		} );
    } );

	wp.customize( 'billow_heading1_font_weight', function( value ) {
        value.bind( function( to ) {
			$( '.billow h1' ).css( 'font-weight', to );
		} );
    } );

	wp.customize( 'billow_heading1_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
			$( '.billow h1' ).css( 'letter-spacing', to );
		} );
    } );

	wp.customize( 'billow_heading1_font_text_transform', function( value ) {
        value.bind( function( to ) {
			$( '.billow h1' ).css( 'text-transform', to );
		} );
    } );

	// Heading H2
	wp.customize( 'billow_heading2_font', function( value ) {
        value.bind( function( to ) {
			$( '.billow h2' ).css( 'font-family', to );
		} );
    } );

	wp.customize( 'billow_heading2_font_size', function( value ) {
        value.bind( function( to ) {
			$( '.billow h2' ).css( 'font-size', to );
		} );
    } );

	wp.customize( 'billow_heading2_font_line_height', function( value ) {
        value.bind( function( to ) {
			$( '.billow h2' ).css( 'line-height', to );
		} );
    } );

	wp.customize( 'billow_heading2_font_weight', function( value ) {
        value.bind( function( to ) {
			$( '.billow h2' ).css( 'font-weight', to );
		} );
    } );

	wp.customize( 'billow_heading2_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
			$( '.billow h2' ).css( 'letter-spacing', to );
		} );
    } );

	wp.customize( 'billow_heading2_font_text_transform', function( value ) {
        value.bind( function( to ) {
			$( '.billow h2' ).css( 'text-transform', to );
		} );
    } );

	// Heading H3
	wp.customize( 'billow_heading3_font', function( value ) {
        value.bind( function( to ) {
			$( '.billow h3' ).css( 'font-family', to );
		} );
    } );

	wp.customize( 'billow_heading3_font_size', function( value ) {
        value.bind( function( to ) {
			$( '.billow h3' ).css( 'font-size', to );
		} );
    } );

	wp.customize( 'billow_heading3_font_line_height', function( value ) {
        value.bind( function( to ) {
			$( '.billow h3' ).css( 'line-height', to );
		} );
    } );

	wp.customize( 'billow_heading3_font_weight', function( value ) {
        value.bind( function( to ) {
			$( '.billow h3' ).css( 'font-weight', to );
		} );
    } );

	wp.customize( 'billow_heading3_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
			$( '.billow h3' ).css( 'letter-spacing', to );
		} );
    } );

	wp.customize( 'billow_heading3_font_text_transform', function( value ) {
        value.bind( function( to ) {
			$( '.billow h3' ).css( 'text-transform', to );
		} );
    } );

	// Heading H4
	wp.customize( 'billow_heading4_font', function( value ) {
        value.bind( function( to ) {
			$( '.billow h4' ).css( 'font-family', to );
		} );
    } );

	wp.customize( 'billow_heading4_font_size', function( value ) {
        value.bind( function( to ) {
			$( '.billow h4' ).css( 'font-size', to );
		} );
    } );

	wp.customize( 'billow_heading4_font_line_height', function( value ) {
        value.bind( function( to ) {
			$( '.billow h4' ).css( 'line-height', to );
		} );
    } );

	wp.customize( 'billow_heading4_font_weight', function( value ) {
        value.bind( function( to ) {
			$( '.billow h4' ).css( 'font-weight', to );
		} );
    } );

	wp.customize( 'billow_heading4_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
			$( '.billow h4' ).css( 'letter-spacing', to );
		} );
    } );

	wp.customize( 'billow_heading4_font_text_transform', function( value ) {
        value.bind( function( to ) {
			$( '.billow h4' ).css( 'text-transform', to );
		} );
    } );

	// Heading H5
	wp.customize( 'billow_heading5_font', function( value ) {
        value.bind( function( to ) {
			$( '.billow h5' ).css( 'font-family', to );
		} );
    } );

	wp.customize( 'billow_heading5_font_size', function( value ) {
        value.bind( function( to ) {
			$( '.billow h5' ).css( 'font-size', to );
		} );
    } );

	wp.customize( 'billow_heading5_font_line_height', function( value ) {
        value.bind( function( to ) {
			$( '.billow h5' ).css( 'line-height', to );
		} );
    } );

	wp.customize( 'billow_heading5_font_weight', function( value ) {
        value.bind( function( to ) {
			$( '.billow h5' ).css( 'font-weight', to );
		} );
    } );

	wp.customize( 'billow_heading5_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
			$( '.billow h5' ).css( 'letter-spacing', to );
		} );
    } );

	wp.customize( 'billow_heading5_font_text_transform', function( value ) {
        value.bind( function( to ) {
			$( '.billow h5' ).css( 'text-transform', to );
		} );
    } );

	// Heading H6
	wp.customize( 'billow_heading6_font', function( value ) {
        value.bind( function( to ) {
			$( '.billow h6' ).css( 'font-family', to );
		} );
    } );

	wp.customize( 'billow_heading6_font_size', function( value ) {
        value.bind( function( to ) {
			$( '.billow h6' ).css( 'font-size', to );
		} );
    } );

	wp.customize( 'billow_heading6_font_line_height', function( value ) {
        value.bind( function( to ) {
			$( '.billow h6' ).css( 'line-height', to );
		} );
    } );

	wp.customize( 'billow_heading6_font_weight', function( value ) {
        value.bind( function( to ) {
			$( '.billow h6' ).css( 'font-weight', to );
		} );
    } );

	wp.customize( 'billow_heading6_font_letter_spacing', function( value ) {
        value.bind( function( to ) {
			$( '.billow h6' ).css( 'letter-spacing', to );
		} );
    } );

	wp.customize( 'billow_heading6_font_text_transform', function( value ) {
        value.bind( function( to ) {
			$( '.billow h6' ).css( 'text-transform', to );
		} );
    } );

	// Button
	wp.customize( 'billow_button_font', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('font-family', to );
		} );
	} );

	wp.customize( 'billow_button_font_size', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('font-size', to );
		} );
	} );

	wp.customize( 'billow_button_font_line_height', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('line-height', to );
		} );
	} );

	wp.customize( 'billow_button_font_weight', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('font-weight', to );
		} );
	} );

	wp.customize( 'billow_button_font_letter_spacing', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('letter-spacing', to );
		} );
	} );

	wp.customize( 'billow_button_font_text_transform', function( value ) {
		value.bind( function( to ) {
			$('.billow .button:not(.customize-partial-edit-shortcut-button), .billow input[type="button"], .billow input[type="reset"], .billow input[type="submit"], .billow button[type="submit"], .billow #page .woocommerce a.button, .billow #page .widget-area a.add_to_cart_button, .billow #page .woocommerce-info a.button, .billow #page .woocommerce-info a.showcoupon, .billow #page .woocommerce-message a.button, .billow #page .woocommerce-message a.showcoupon, .billow #page .woocommerce-error a.button, .billow #page .woocommerce-error a.showcoupon, .billow #page .single-product-wrapper a.button, .billow #page .single-product-wrapper a.added_to_cart, .billow #page .woocommerce-pagination ul.page-numbers li .current, .billow #page .navigation.pagination .nav-links > *.current').css('text-transform', to );
		} );
	} );

	// Single Post
	wp.customize( 'billow_single_content_padding_top', function( value ) {
		value.bind( function( to ) {
			$('.billow.single-post .site-content > .container.site-main').css('padding-top', to );
		} );
	} );

	wp.customize( 'billow_single_content_padding_bottom', function( value ) {
		value.bind( function( to ) {
			$('.billow.single-post .site-content > .container.site-main').css('padding-bottom', to );
		} );
	} );

	wp.customize( 'billow_single_post_title_color', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay h1.entry-title').css('color', to );
		} );
	} );

	wp.customize( 'billow_single_post_title_font', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay h1.entry-title').css('font-family', to );
		} );
	} );

	wp.customize( 'billow_single_post_title_font_size', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay h1.entry-title').css('font-size', to );
		} );
	} );

	wp.customize( 'billow_single_post_title_font_line_height', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay h1.entry-title').css('line-height', to );
		} );
	} );

	wp.customize( 'billow_single_post_title_font_weight', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay h1.entry-title').css('font-weight', to );
		} );
	} );

	wp.customize( 'billow_single_post_title_font_letter_spacing', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay h1.entry-title').css('letter-spacing', to );
		} );
	} );

	wp.customize( 'billow_single_post_title_font_text_transform', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay h1.entry-title').css('text-transform', to );
		} );
	} );

	wp.customize( 'billow_single_post_meta_color', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay .entry-meta').css('color', to );
		} );
	} );

	wp.customize( 'billow_single_post_meta_font', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay .entry-meta').css('font-family', to );
		} );
	} );

	wp.customize( 'billow_single_post_meta_font_size', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay .entry-meta').css('font-size', to );
		} );
	} );

	wp.customize( 'billow_single_post_meta_font_line_height', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay .entry-meta').css('line-height', to );
		} );
	} );

	wp.customize( 'billow_single_post_meta_font_weight', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay .entry-meta').css('font-weight', to );
		} );
	} );

	wp.customize( 'billow_single_post_meta_font_letter_spacing', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay .entry-meta').css('letter-spacing', to );
		} );
	} );

	wp.customize( 'billow_single_post_meta_font_text_transform', function( value ) {
		value.bind( function( to ) {
			$('body.billow header.post-entry-header .blw-overlay .entry-meta').css('text-transform', to );
		} );
	} );

	// Nav Post
	wp.customize( 'billow_post_nav_font', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links div a').css('font-family', to );
		} );
	} );

	wp.customize( 'billow_post_nav_font_size', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links div a').css('font-size', to );
		} );
	} );

	wp.customize( 'billow_post_nav_font_line_height', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links div a').css('line-height', to );
		} );
	} );

	wp.customize( 'billow_post_nav_font_weight', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links div a').css('font-weight', to );
		} );
	} );

	wp.customize( 'billow_post_nav_font_letter_spacing', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links div a').css('letter-spacing', to );
		} );
	} );

	wp.customize( 'billow_post_nav_font_text_transform', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links div a').css('text-transform', to );
		} );
	} );

	wp.customize( 'billow_post_nav_color', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links div a .nav-title, .billow nav.navigation .nav-links div .nav-icon').css('color', to );
			$('.billow.theme-style-green nav.navigation .nav-links div a .nav-title, .billow.theme-style-green nav.navigation .nav-links div .nav-icon').css('color', to );
			$('.billow.theme-style-violet nav.navigation .nav-links div a .nav-title, .billow.theme-style-violet nav.navigation .nav-links div .nav-icon').css('color', to );
			$('.billow.theme-style-yellow nav.navigation .nav-links div a .nav-title, .billow.theme-style-yellow nav.navigation .nav-links div .nav-icon').css('color', to );
		} );
	} );

	wp.customize( 'billow_post_nav_hover_color', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links div a:hover .nav-title, .billow nav.navigation .nav-links div a:hover .nav-icon').css('color', to );
			$('.billow.theme-style-green nav.navigation .nav-links div a:hover .nav-title, .billow.theme-style-green nav.navigation .nav-links div a:hover .nav-icon').css('color', to );
			$('.billow.theme-style-violet nav.navigation .nav-links div a:hover .nav-title, .billow.theme-style-violet nav.navigation .nav-links div a:hover .nav-icon').css('color', to );
			$('.billow.theme-style-yellow nav.navigation .nav-links div a:hover .nav-title, .billow.theme-style-yellow nav.navigation .nav-links div a:hover .nav-icon').css('color', to );
		} );
	} );

	wp.customize( 'billow_post_nav_bc', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links').css('background-color', to );
		} );
	} );

	wp.customize( 'billow_post_nav_padding_top', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links').css('padding-top', to );
		} );
	} );

	wp.customize( 'billow_post_nav_padding_bottom', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links').css('padding-bottom', to );
		} );
	} );

	wp.customize( 'billow_post_nav_padding_right', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links').css('padding-right', to );
		} );
	} );

	wp.customize( 'billow_post_nav_padding_left', function( value ) {
		value.bind( function( to ) {
			$('.billow nav.navigation .nav-links').css('padding-left', to );
		} );
	} );

	// Social Networks
	wp.customize( 'billow_social_links_size', function( value ) {
		value.bind( function( to ) {
			$('.billow ul.social-networks li a i.fab').css('font-size', to );
		} );
	} );

	wp.customize( 'billow_social_links_spacing', function( value ) {
		value.bind( function( to ) {
			$('.billow ul.social-networks li a').css('margin-top', to );
			$('.billow ul.social-networks li a').css('margin-left', to );
			$('.billow ul.social-networks li a').css('margin-right', to );
		} );
	} );

	wp.customize( 'billow_social_links_color_custom', function( value ) {
		value.bind( function( to ) {
			$('.billow.blw-social-icon-custom ul.social-networks li a').css('color', to );
			$('.billow.blw-social-icon-custom .post-entry-header ul.social-networks li a').css('color', to );
			$('.billow.blw-social-icon-custom.blw-social-icon-rounded ul.social-networks li a, .billow.blw-social-icon-custom.blw-social-icon-square ul.social-networks li a').css('color', to );
			$('.billow.blw-social-icon-custom.blw-social-icon-rounded .post-entry-header ul.social-networks li a, .billow.blw-social-icon-custom.blw-social-icon-square .post-entry-header ul.social-networks li a').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom ul.social-networks li a').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom #page .post-entry-header ul.social-networks li a').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-rounded #page .post-entry-header ul.social-networks li a, .billow.theme-style-green.blw-social-icon-custom.blw-social-icon-square #page .post-entry-header ul.social-networks li a').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a, .billow.theme-style-green.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom #page footer.site-footer ul.social-networks li a').css('color', to );
			$('.billow.theme-style-violet.blw-social-icon-custom ul.social-networks li a').css('color', to );
			$('.billow.theme-style-violet.blw-social-icon-rounded.blw-social-icon-custom ul.social-networks li a, .billow.theme-style-violet.blw-social-icon-square.blw-social-icon-custom ul.social-networks li a').css('color', to );
			$('.billow.theme-style-violet.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a, .billow.theme-style-violet.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a').css('color', to );
			$('.billow.theme-style-yellow.blw-social-icon-custom ul.social-networks li a').css('color', to );
			$('.billow.theme-style-yellow.blw-social-icon-rounded.blw-social-icon-custom ul.social-networks li a, .billow.theme-style-yellow.blw-social-icon-square.blw-social-icon-custom ul.social-networks li a').css('color', to );
			$('.billow.theme-style-yellow.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a, .billow.theme-style-yellow.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a').css('color', to );
		} );
	} );

	wp.customize( 'billow_social_links_color_custom', function( value ) {
		value.bind( function( to ) {
			$('.billow.blw-social-icon-custom ul.social-networks li a:hover').css('color', to );
			$('.billow.blw-social-icon-custom .post-entry-header ul.social-networks li a:hover').css('color', to );
			$('.billow.blw-social-icon-custom.blw-social-icon-rounded ul.social-networks li a:hover, .billow.blw-social-icon-custom.blw-social-icon-square ul.social-networks li a:hover').css('color', to );
			$('.billow.blw-social-icon-custom.blw-social-icon-rounded .post-entry-header ul.social-networks li a:hover, .billow.blw-social-icon-custom.blw-social-icon-square .post-entry-header ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom #page .post-entry-header ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-rounded #page .post-entry-header ul.social-networks li a:hover, .billow.theme-style-green.blw-social-icon-custom.blw-social-icon-square #page .post-entry-header ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a:hover, .billow.theme-style-green.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-green.blw-social-icon-custom #page footer.site-footer ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-violet.blw-social-icon-custom ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-violet.blw-social-icon-rounded.blw-social-icon-custom ul.social-networks li a:hover, .billow.theme-style-violet.blw-social-icon-square.blw-social-icon-custom ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-violet.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a:hover, .billow.theme-style-violet.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-yellow.blw-social-icon-custom ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-yellow.blw-social-icon-rounded.blw-social-icon-custom ul.social-networks li a:hover, .billow.theme-style-yellow.blw-social-icon-square.blw-social-icon-custom ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-yellow.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a:hover, .billow.theme-style-yellow.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a:hover').css('color', to );
			$('.billow.theme-style-yellow.blw-social-icon-custom #page footer.site-footer ul.social-networks li a, .billow.theme-style-yellow.blw-social-icon-custom #page footer.site-footer ul.social-networks li a:hover').css('color', to );
		} );
	} );

	wp.customize( 'billow_social_links_rounded_bc_color', function( value ) {
		value.bind( function( to ) {
			$('.billow.blw-social-icon-rounded ul.social-networks li a').css('background-color', to );
		} );
	} );

	wp.customize( 'billow_social_links_hover_rounded_bc_color', function( value ) {
		value.bind( function( to ) {
			$('.billow.blw-social-icon-rounded ul.social-networks li a:hover').css('background-color', to );
			$('.billow.theme-style-green.blw-social-icon-rounded ul.social-networks li a:hover').css('background-color', to );
			$('.billow.theme-style-violet.blw-social-icon-rounded ul.social-networks li a:hover').css('background-color', to );
			$('.billow.theme-style-yellow.blw-social-icon-rounded ul.social-networks li a:hover').css('background-color', to );
		} );
	} );

	wp.customize( 'billow_social_links_hover_square_bc_color', function( value ) {
		value.bind( function( to ) {
			$('.billow.blw-social-icon-square ul.social-networks li a').css('background-color', to );
		} );
	} );
	
	wp.customize( 'billow_social_links_hover_square_bc_color', function( value ) {
		value.bind( function( to ) {
			$('.billow.blw-social-icon-square ul.social-networks li a:hover').css('background-color', to );
			$('.billow.theme-style-green.blw-social-icon-square ul.social-networks li a:hover').css('background-color', to );
			$('.billow.theme-style-violet.blw-social-icon-square ul.social-networks li a:hover').css('background-color', to );
			$('.billow.theme-style-yellow.blw-social-icon-square ul.social-networks li a:hover').css('background-color', to );
		} );
	} );

	// Sidebar
	wp.customize( 'billow_sidebar_font', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) .widget .widget-title').css('font-family', to );
		} );
	} );

	wp.customize( 'billow_sidebar_font_size', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) .widget .widget-title').css('font-size', to );
		} );
	} );

	wp.customize( 'billow_sidebar_font_line_height', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) .widget .widget-title').css('line-height', to );
		} );
	} );

	wp.customize( 'billow_sidebar_font_weight', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) .widget .widget-title').css('font-weight', to );
		} );
	} );

	wp.customize( 'billow_sidebar_font_letter_spacing', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) .widget .widget-title').css('letter-spacing', to );
		} );
	} );

	wp.customize( 'billow_sidebar_font_text_transform', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) .widget .widget-title').css('text-transform', to );
		} );
	} );

	wp.customize( 'billow_sidebar_title_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) .widget .widget-title').css('color', to );
		} );
	} );

	wp.customize( 'billow_sidebar_text_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) span, .billow .widget-area:not(.footer-widget-area) ul li, .billow .widget-area:not(.footer-widget-area) .widget_text .textwidget p, .billow .widget-area:not(.footer-widget-area) .widget_calendar table.wp-calendar-table, .billow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content .post-meta a.date-link').css('color', to );
		} );
	} );

	wp.customize( 'billow_sidebar_link_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) a, .billow .widget-area:not(.footer-widget-area) .widget ul li a, .billow .widget-area:not(.footer-widget-area) .widget_text .textwidget p a, .billow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title, .billow .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a').css('color', to );
			$('.billow.theme-style-green .widget-area:not(.footer-widget-area) a, .billow.theme-style-green .widget-area:not(.footer-widget-area) .widget ul li a, .billow.theme-style-green .widget-area:not(.footer-widget-area) .widget_text .textwidget p a, .billow.theme-style-green .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title, .billow.theme-style-green .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a').css('color', to );
			$('.billow.theme-style-violet .widget-area:not(.footer-widget-area) a, .billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget ul li a, .billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget_text .textwidget p a, .billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title, .billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a').css('color', to );
			$('.billow.theme-style-yellow .widget-area:not(.footer-widget-area) a, .billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget ul li a, .billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget_text .textwidget p a, .billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title, .billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a').css('color', to );
		} );
	} );
	
	wp.customize( 'billow_sidebar_hover_link_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .widget-area:not(.footer-widget-area) a:hover, .billow .widget-area:not(.footer-widget-area) .widget ul li a:hover, .billow .widget-area:not(.footer-widget-area) .widget_text .textwidget p a:hover, .billow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title:hover, .billow .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a:hover').css('color', to );
			$('.billow.theme-style-green .widget-area:not(.footer-widget-area) a:hover, .billow.theme-style-green .widget-area:not(.footer-widget-area) .widget ul li a:hover, .billow.theme-style-green .widget-area:not(.footer-widget-area) .widget_text .textwidget p a:hover, .billow.theme-style-green .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title:hover, .billow.theme-style-green .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a:hover').css('color', to );
			$('.billow.theme-style-violet .widget-area:not(.footer-widget-area) a:hover, .billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget ul li a:hover, .billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget_text .textwidget p a:hover, .billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title:hover, .billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a:hover').css('color', to );
			$('.billow.theme-style-yellow .widget-area:not(.footer-widget-area) a:hover, .billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget ul li a:hover, .billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget_text .textwidget p a:hover, .billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title:hover, .billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a:hover').css('color', to );
		} );
	} );

	wp.customize( 'billow_sidebar_bc_color', function( value ) {
		value.bind( function( to ) {
			$('.billow .shop-wrapper aside.widget-area, .billow .main-wrap aside.widget-area').css('background-color', to );
		} );
	} );

	wp.customize( 'billow_footer_widget_title_color', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .footer-widget-area ul.widget li.widget .widget-title').css('color', to );
		} );
	} );

	wp.customize( 'billow_footer_widget_text_color', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .footer-widget-area span, .billow footer.site-footer .footer-widget-area figcaption, .billow footer.site-footer .footer-widget-area .widget footer, .billow footer.site-footer .footer-widget-area .widget p, .billow footer.site-footer .footer-widget-area .widget cite, .billow footer.site-footer .footer-widget-area .widget ul li, .billow footer.site-footer .footer-widget-area .widget_text .textwidget p, .billow footer.site-footer .footer-widget-area .widget_calendar table.wp-calendar-table, .billow footer.site-footer .footer-widget-area .widget_calendar table.wp-calendar-table th, .billow footer.site-footer .footer-widget-area .widget_calendar table.wp-calendar-table td, .billow footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content .post-meta a.date-link, .billow footer.site-footer .footer-widget-area .widget label').css('color', to );
		} );
	} );

	wp.customize( 'billow_footer_widget_link_color', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .footer-widget-area a, .billow footer.site-footer .footer-widget-area .widget ul li a, .billow footer.site-footer .footer-widget-area .widget_text .textwidget p a, .billow footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title, .billow footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a').css('color', to );
		} );
	} );

	wp.customize( 'billow_footer_widget_hover_link_color', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .footer-widget-area a:hover, .billow footer.site-footer .footer-widget-area .widget ul li a:hover, .billow footer.site-footer .footer-widget-area .widget_text .textwidget p a:hover, .billow footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title:hover, .billow footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a:hover').css('color', to );
			$('.billow.theme-style-green footer.site-footer .footer-widget-area a:hover, .billow.theme-style-green footer.site-footer .footer-widget-area .widget ul li a:hover, .billow.theme-style-green footer.site-footer .footer-widget-area .widget_text .textwidget p a:hover, .billow.theme-style-green footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title:hover, .billow.theme-style-green footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a:hover').css('color', to );
			$('.billow.theme-style-violet footer.site-footer .footer-widget-area a:hover, .billow.theme-style-violet footer.site-footer .footer-widget-area .widget ul li a:hover, .billow.theme-style-violet footer.site-footer .footer-widget-area .widget_text .textwidget p a:hover, .billow.theme-style-violet footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title:hover, .billow.theme-style-violet footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a:hover').css('color', to );
			$('.billow.theme-style-yellow footer.site-footer .footer-widget-area a:hover, .billow.theme-style-yellow footer.site-footer .footer-widget-area .widget ul li a:hover, .billow.theme-style-yellow footer.site-footer .footer-widget-area .widget_text .textwidget p a:hover, .billow.theme-style-yellow footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title:hover, .billow.theme-style-yellow footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a:hover').css('color', to );
		} );
	} );

	wp.customize( 'billow_footer_bc_color', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .footer-widget-area').css('background-color', to );
			$('.billow.theme-style-green footer.site-footer .footer-widget-area').css('background-color', to );
			$('.billow.theme-style-violet footer.site-footer .footer-widget-area').css('background-color', to );
			$('.billow.theme-style-yellow footer.site-footer .footer-widget-area').css('background-color', to );
		} );
	} );

	// Copyright
	wp.customize( 'billow_copyright_bc_color', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info').css('background-color', to );
			$('.billow.theme-style-green footer.site-footer .site-info').css('background-color', to );
			$('.billow.theme-style-violet footer.site-footer .site-info').css('background-color', to );
			$('.billow.theme-style-yellow footer.site-footer .site-info').css('background-color', to );
		} );
	} );

	wp.customize( 'billow_copyright_font_color', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info').css('color', to );
		} );
	} );

	wp.customize( 'billow_copyright_font', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info .container').css('font-family', to );
		} );
	} );

	wp.customize( 'billow_copyright_font_size', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info .container').css('font-size', to );
		} );
	} );

	wp.customize( 'billow_copyright_font_line_height', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info .container').css('line-height', to );
		} );
	} );

	wp.customize( 'billow_copyright_font_weight', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info .container').css('font-weight', to );
		} );
	} );

	wp.customize( 'billow_copyright_font_letter_spacing', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info .container').css('letter-spacing', to );
		} );
	} );

	wp.customize( 'billow_copyright_font_text_transform', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info .container').css('text-transform', to );
		} );
	} );

	wp.customize( 'billow_copyright_border', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info').css('border-top-width', to + 'px' );
		} );
	} );
	
	wp.customize( 'billow_copyright_border_style', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info').css('border-top-style', to );
		} );
	} );

	wp.customize( 'billow_copyright_border_color', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info').css('border-top-color', to );
		} );
	} );

	wp.customize( 'billow_copyright_padding_top', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info').css('padding-top', to );
		} );
	} );

	wp.customize( 'billow_copyright_padding_bottom', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info').css('padding-bottom', to );
		} );
	} );

	wp.customize( 'billow_copyright_padding_right', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info').css('padding-right', to );
		} );
	} );

	wp.customize( 'billow_copyright_padding_left', function( value ) {
		value.bind( function( to ) {
			$('.billow footer.site-footer .site-info').css('padding-left', to );
		} );
	} );

	// Header Layout
	wp.customize( 'billow_header_layout_align', function( value ) {
		value.bind( function ( to ) {
			$( ".billow header.site-header .header-wrap .container" ).removeClass ( function ( index, className ) {
				return ( className.match (/(^|\s)header-(left|center|right)/g) || [] ).join( ' ' );
			} );
			$( '.billow header.site-header .header-wrap .container' ).addClass( to );
		} );
	});

	// Blog/Category/Archive/Search Sidebar Layout
	wp.customize( 'billow_posts_sidebar_position', function( value ) {
		value.bind( function ( to ) {
			$( ".blog .blw-blog-site-main .main-wrap, .archive .site-main .main-wrap, .category .site-main .main-wrap, .tag .site-main .main-wrap, .search .site-main .main-wrap" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)sidebar-(none|right|left)/g ) || [] ).join( ' ' );
			} );
			$( '.blog .blw-blog-site-main .main-wrap, .archive .site-main .main-wrap, .category .site-main .main-wrap, .tag .site-main .main-wrap, .search .site-main .main-wrap' ).addClass( to );
		} );
	} );

	// Post Sidebar Layout
	wp.customize( 'billow_post_sidebar_position', function( value ) {
		value.bind( function ( to ) {
			$( ".single-post .site-main .main-wrap" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)sidebar-(none|right|left)/g ) || [] ).join( ' ' );
			});
			$( '.single-post .site-main .main-wrap' ).addClass( to );
		} );
	} );

	// Single Product Sidebar Layout
	wp.customize( 'billow_single_product_sidebar_position', function( value ) {
		value.bind( function ( to ) {
			$( ".single-product .content-area .single-product-wrapper" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)sidebar-(none|right|left)/g ) || [] ).join( ' ' );
			} );
			$( '.single-product .content-area .single-product-wrapper' ).addClass( to );
		} );
	} );

	// Shop Sidebar Layout
	wp.customize( 'billow_shop_sidebar_position', function( value ) {
		value.bind( function ( to ) {
			$( ".post-type-archive-product .site .content-area .shop-wrapper" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)sidebar-(none|right|left)/g ) || [] ).join( ' ' );
			} );
			$( '.post-type-archive-product .site .content-area .shop-wrapper' ).addClass( to );
		} );
	} );

	// Front Page Title Align
	wp.customize( 'billow_home_page_horizontal_align', function( value ) {
		value.bind( function ( to ) {
			$( ".blw-hero-area .hero-content" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)(left|center|right)/g ) || [] ).join( ' ' );
			} );
			$( '.blw-hero-area .hero-content' ).addClass( to );
		} );
	} );

	// Blog Title Align
	wp.customize( 'billow_posts_title_align', function( value ) {
		value.bind( function ( to ) {
			$( ".billow.archive header.archive-header, .billow.blog header.blw-blog-page-header, .billow.search header.search-header" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)title-(left|center|right)/g ) || [] ).join( ' ' );
			} );
			$( '.billow.archive header.archive-header, .billow.blog header.blw-blog-page-header, .billow.search header.search-header' ).addClass( to );
		} );
	} );

	// Blog Background Align
	wp.customize( 'billow_posts_bc_align', function( value ) {
		value.bind( function ( to ) {
			$( ".billow.archive header.archive-header span.archive-background, .billow.blog header.blw-blog-page-header span.background, .billow.search header.search-header span.search-background" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)bc-(left|center|right)/g ) || [] ).join( ' ' );
			} );
			$( '.billow.archive header.archive-header span.archive-background, .billow.blog header.blw-blog-page-header span.background, .billow.search header.search-header span.search-background' ).addClass( to );
		} );
	} );

	// Blog Structure
	wp.customize( 'billow_posts_structure', function( value ) {
		value.bind( function ( to ) {
			$( ".billow .main-wrap .main-content" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)(classic|simple|grid|gutenberg)/g ) || [] ).join( ' ' );
			} );
			$( '.billow .main-wrap .main-content' ).addClass( to );
		} );
	} );

	// Socials Align
	wp.customize( 'billow_social_links_align', function( value ) {
		value.bind( function ( to ) {
			$( "ul.social-networks" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)align-(left|center|right)/g ) || [] ).join( ' ' );
			} );
			$( 'ul.social-networks' ).addClass( to );
		} );
	} );

	// Scroll to Top Align
	wp.customize( 'billow_scroll_top_align', function( value ) {
		value.bind( function ( to ) {
			$( "a#scroll-to-top" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)(left|center|right)/g ) || [] ).join( ' ' );
			} );
			$( 'a#scroll-to-top' ).addClass( to );
		} );
	} );

	// Scroll to Top Icon Type
	wp.customize( 'billow_scroll_top_icon_type', function( value ) {
		value.bind( function ( to ) {
			$( "a#scroll-to-top" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)type-(1|2|3)/g) || [] ).join( ' ' );
			} );
			$( 'a#scroll-to-top' ).addClass( to );
		} );
	} );

	// Scroll to Top Button Type
	wp.customize( 'billow_scroll_top_button_type', function( value ) {
		value.bind( function ( to ) {
			$( "a#scroll-to-top" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)(square|circle)/g ) || [] ).join( ' ' );
			} );
			$( 'a#scroll-to-top' ).addClass( to );
		} );
	} );

	// Footer Align
	wp.customize( 'billow_copyright_align', function( value ) {
		value.bind( function ( to ) {
			$( ".site-footer .site-info .container" ).removeClass ( function ( index, className ) {
				return ( className.match ( /(^|\s)align-(left|center|right)/g ) || [] ).join( ' ' );
			} );
			$( '.site-footer .site-info .container' ).addClass( to );
		} );
	} );
}( jQuery ) );
